@@ -17,7 +17,7 @@ test -z "$srcdir" && srcdir=.
 
 PKG_NAME="hildon-notifymm"
 
-(test -f $srcdir/configure.in \
+(test -f $srcdir/configure.ac \
   && test -d $srcdir/hildon-notify/src \
   && test -d $srcdir/hildon-notify/hildon-notifymm) || {
     echo -n "**Error**: Directory "\`$srcdir\'" does not look like the"
